..
   Copyright (C) 2024 Roberto Rossini <roberros@uio.no>
   SPDX-License-Identifier: MIT

Hi-C API
########

.. py:module:: hictkpy.hic
.. py:currentmodule:: hictkpy.hic

.. autoclass:: FileWriter

   .. automethod:: __init__
   .. automethod:: add_pixels
   .. automethod:: bins
   .. automethod:: chromosomes
   .. automethod:: finalize
   .. automethod:: path
   .. automethod:: resolutions
